*************************************************************************************************************
* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * 
*			                               Replication file for:     		           	        	        *
*     				  "Congruence, National Context and Trust in European Institutions"   					*
* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * 
*																						 	  				*			
* Author: 			Mariano Torcal and Pablo Christmann       						                     	*
* Contact: 			mariano.torcal@upf.edu, pablo.christmann@gesis.org                     					*
* Date: 			22nd of October 2018 	                                                     			*
* Version:			Stata 15.1                                                              				*                                                                          
* Dataset:          CIUPANEL.dta                                                						*		
* Logfile: 			CIUPANEL.txt													 					*
*																											*
* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * 
*************************************************************************************************************

set more off
clear all

*** Install required packages
ssc install outreg2
ssc install norm

*** Set directory to the location where replication files have been saved, for example:
cd "C:\Replication Materials JEPP"

*** Opening log
capture log close _all
log using CIUPANEL.log, name(CIUPANEL) replace 

*** Load CIUPANEL Data. 
use "CIUPANEL.dta", clear

************************
*** Generate Indices ***
************************
*** Generate tust in representative institutions of the EU index
gen trust_EU_rep = (CONFI_PARLAM_EU + CONFI_COMMISION_EU)/2

*** Generate tust in representative institutions (Spain) index 
gen trust_rep = (CONFI_PARLAM + CONFI_GOVERNMENT)/2

*** Generate personal economic situation index
factor ECON1 ECON2 ECON3 ECON4, ipf factors(1)
alpha ECON1 ECON2 ECON3 ECON4
predict F_ECON_INSECURE

*** Generate economic situation in Spain index
factor SOCIOTROP_PROSP SOCIOTROP_RETROSP  , ipf factors(1)
alpha SOCIOTROP_PROSP SOCIOTROP_RETROSP
predict ECONOMY

*** Generate social trust index
factor SOCIAL_TRUST_1 SOCIAL_TRUST_2 SOCIAL_TRUST_3, ipf factors(1)
alpha SOCIAL_TRUST_1 SOCIAL_TRUST_2 SOCIAL_TRUST_3
predict SOCIAL_TRUST

******************************************************************************************
*** Generate group-meaned and demeaned terms for "within-between" random effects model ***
******************************************************************************************

egen F_ECON_INSECURE_mean = mean(F_ECON_INSECURE), by(id)
gen F_ECON_INSECURE_w = F_ECON_INSECURE  - F_ECON_INSECURE_mean

egen ECONOMY_mean = mean(ECONOMY), by(id)
gen ECONOMY_w = ECONOMY  - ECONOMY_mean

egen GOV_APROVE_mean = mean(GOV_APROVE), by(id)
gen GOV_APROVE_w = GOV_APROVE  - GOV_APROVE_mean

egen SOCIAL_TRUST_mean = mean(SOCIAL_TRUST), by(id)
gen SOCIAL_TRUST_w = SOCIAL_TRUST  - SOCIAL_TRUST_mean

egen Approve_EU_mean = mean(Approve_EU), by(id)
gen Approve_EU_w = Approve_EU  - Approve_EU_mean

egen INFO_EU_mean = mean(INFO_EU), by(id)
gen INFO_EU_w = INFO_EU  - INFO_EU_mean

egen IDEOLOGY_mean = mean(IDEOLOGY), by(id)
gen IDEOLOGY_w = IDEOLOGY - IDEOLOGY_mean

egen INT_POL_mean = mean(INT_POL), by(id)
gen INT_POL_w = INT_POL - INT_POL_mean

egen AGE_mean = mean(AGE), by(id)
egen Education_mean = mean(estudios_), by(id)

egen CONFI_PARLAM_mean = mean(CONFI_PARLAM), by (id)
gen CONFI_PARLAM_w = CONFI_PARLAM  - CONFI_PARLAM_mean

egen CONFI_GOVERNMENT_mean = mean(CONFI_GOVERNMENT), by (id)
gen CONFI_GOVERNMENT_w = CONFI_GOVERNMENT  - CONFI_GOVERNMENT_mean

**************************
*** Drop missing cases ***
**************************
drop if MAN ==.
drop if AGE ==.
drop if estudios_==.
drop if ECON1==.
drop if ECON2==.
drop if ECON3==.
drop if ECON4==.
drop if INT_POL ==.
drop if IDEOLOGY ==.
drop if SOCIAL_TRUST ==.
drop if F_ECON_INSECURE ==.
drop if ECONOMY ==.
drop if GOV_APROVE ==.
drop if INFO_EU ==.
drop if Approve_EU ==.
drop if CONFI_PARLAM_EU ==.
drop if CONFI_PARLAM ==.
drop if CONFI_GOVERNMENT==.
drop if CONFI_COMMISION_EU==.

egen trust_rep_mean = mean(trust_rep), by(id)
gen trust_rep_w = trust_rep  - trust_rep_mean

**********************************************
*** Standardization of Continous Variables ***
**********************************************
*** Note: All standardized variables have the prefix zee_ 
norm AGE_mean, method(zee)
norm Education_mean, method(zee)
norm IDEOLOGY_mean, method(zee)
norm F_ECON_INSECURE_mean, method(zee)
norm INT_POL_mean, method(zee)
norm Approve_EU_mean, method(zee)
norm ECONOMY_mean, method(zee)
norm SOCIAL_TRUST_mean, method(zee)
norm GOV_APROVE_mean, method(zee)
norm INFO_EU_mean, method(zee)
norm trust_rep_mean, method(zee)
norm CONFI_GOVERNMENT_mean, method(zee)
norm CONFI_PARLAM_mean, method(zee)

norm IDEOLOGY_w, method(zee)
norm F_ECON_INSECURE_w, method(zee)
norm INT_POL_w, method(zee)
norm Approve_EU_w, method(zee)
norm ECONOMY_w, method(zee)
norm SOCIAL_TRUST_w, method(zee)
norm GOV_APROVE_w, method(zee)
norm INFO_EU_w, method(zee)
norm trust_rep_w, method(zee)
norm CONFI_GOVERNMENT_w, method(zee)
norm CONFI_PARLAM_w, method(zee)

******************************************************
*** Multivariate Analysis (Table 2)                ***
******************************************************
xtmixed  trust_EU_rep  || id: , var // Within Terms
outreg2 using "Table_2.ster", replace ctitle(NULL) dec(2) onecol alpha(0.001,0.01,0.05,0.1) symbol(***,**,*,+)
outreg2 using "Table_2.xls",  excel replace  ctitle(NULL1)  dec(2) onecol alpha(0.001,0.01,0.05,0.1) symbol(***,**,*,+)
estat icc
estat ic

xtmixed  trust_EU_rep  zee_AGE_mean MAN zee_Education_mean  /// Time-invariant variables
zee_IDEOLOGY_mean  zee_INT_POL_mean  zee_SOCIAL_TRUST_mean  c.zee_F_ECON_INSECURE_mean c.zee_GOV_APROVE_mean zee_INFO_EU_mean zee_Approve_EU_mean c.zee_ECONOMY_mean c.zee_trust_rep_mean /// Mean Terms
zee_IDEOLOGY_w  zee_INT_POL_w  zee_SOCIAL_TRUST_w  zee_F_ECON_INSECURE_w zee_ECONOMY_w zee_GOV_APROVE_w zee_INFO_EU_w zee_Approve_EU_w c.zee_trust_rep_w || id: , var  // Within Terms     
outreg2 using "Table_2.ster", append ctitle(NULL) dec(2) onecol alpha(0.001,0.01,0.05,0.1) symbol(***,**,*,+)
outreg2 using "Table_2.xls",  excel append  ctitle(NULL1)  dec(2) onecol alpha(0.001,0.01,0.05,0.1) symbol(***,**,*,+)
estat icc
estat ic
estimates store trust_EU_rep

*** Figure N. Marginal Effects Plots
coefplot (trust_EU_rep, label(Trust in European Parliament)), drop(_cons zee_AGE_mean MAN zee_Education_mean zee_IDEOLOGY_mean zee_INT_POL_mean zee_SOCIAL_TRUST_mean zee_F_ECON_INSECURE_mean zee_GOV_APROVE_mean zee_INFO_EU_mean zee_Approve_EU_mean zee_ECONOMY_mean zee_trust_rep_mean) xline(0)
graph save "Figure_Na.gph", replace
graph export "Figure_Na.tif", as(tif) width(2550) replace 

coefplot (trust_EU_rep, label(Trust in European Parliament)), drop(_cons zee_IDEOLOGY_w zee_INT_POL_w zee_SOCIAL_TRUST_w zee_F_ECON_INSECURE_w zee_GOV_APROVE_w zee_INFO_EU_w zee_Approve_EU_w zee_ECONOMY_w zee_trust_rep_w) xline(0)
graph save "Figure_Nb.gph", replace
graph export "Figure_Nb.tif", as(tif) width(2550) replace 


************************************
////////////////////////////////////
////////////////////////////////////
*** Additional Robustness Checks ***
////////////////////////////////////
////////////////////////////////////
************************************

***********************************************************
*** Replication of Table 2 using Robust Standard Errors ***
***********************************************************
xtmixed  trust_EU_rep  zee_AGE_mean MAN zee_Education_mean  /// Time-invariant variables
zee_IDEOLOGY_mean  zee_INT_POL_mean  zee_SOCIAL_TRUST_mean  c.zee_F_ECON_INSECURE_mean c.zee_GOV_APROVE_mean zee_INFO_EU_mean zee_Approve_EU_mean c.zee_ECONOMY_mean c.zee_trust_rep_mean /// Mean Terms
zee_IDEOLOGY_w  zee_INT_POL_w  zee_SOCIAL_TRUST_w  zee_F_ECON_INSECURE_w zee_ECONOMY_w zee_GOV_APROVE_w zee_INFO_EU_w zee_Approve_EU_w c.zee_trust_rep_w || id: , var  robust // Within Terms   

******************************************************************************
*** OLS Regression with Lagged Predictors (Table H in the Online Appendix) ***
******************************************************************************

xtset id wave

***Generate standardized lagged variables
gen AGE_w2 = AGE if wave==2
gen AGE_w3 = AGE if wave==3
norm AGE_w2, method(zee)
norm AGE_w3, method(zee)
gen zee_AGE = zee_AGE_w2
replace zee_AGE = zee_AGE_w3 if zee_AGE==.

gen IDEOLOGY_w2 = IDEOLOGY if wave==2
gen IDEOLOGY_w3 = IDEOLOGY if wave==3
norm IDEOLOGY_w2, method(zee)
norm IDEOLOGY_w3, method(zee)
gen zee_IDEOLOGY = zee_IDEOLOGY_w2
replace zee_IDEOLOGY = zee_IDEOLOGY_w3 if zee_IDEOLOGY==.

gen INT_POL_w2 = INT_POL if wave==2
gen INT_POL_w3 = INT_POL if wave==3
norm INT_POL_w2, method(zee)
norm INT_POL_w3, method(zee)
gen zee_INT_POL = zee_INT_POL_w2
replace zee_INT_POL = INT_POL_w3 if zee_INT_POL==.

gen SOCIAL_TRUST_w2 = SOCIAL_TRUST if wave==2
gen SOCIAL_TRUST_w3 = SOCIAL_TRUST if wave==3
norm SOCIAL_TRUST_w2, method(zee)
norm SOCIAL_TRUST_w3, method(zee)
gen zee_SOCIAL_TRUST = zee_SOCIAL_TRUST_w2
replace zee_SOCIAL_TRUST = zee_SOCIAL_TRUST_w3 if zee_SOCIAL_TRUST==.

gen F_ECON_INSECURE_w2 = F_ECON_INSECURE if wave==2
gen F_ECON_INSECURE_w3 = F_ECON_INSECURE if wave==3
norm F_ECON_INSECURE_w2, method(zee)
norm F_ECON_INSECURE_w3, method(zee)
gen zee_F_ECON_INSECURE = zee_F_ECON_INSECURE_w2
replace zee_F_ECON_INSECURE = zee_F_ECON_INSECURE_w3 if zee_F_ECON_INSECURE==.

gen GOV_APROVE_w2 = GOV_APROVE if wave==2
gen GOV_APROVE_w3 = GOV_APROVE if wave==3
norm GOV_APROVE_w2, method(zee)
norm GOV_APROVE_w3, method(zee)
gen zee_GOV_APROVE = zee_GOV_APROVE_w2
replace zee_GOV_APROVE = zee_GOV_APROVE_w3 if zee_GOV_APROVE==.

gen Approve_EU_w2 = Approve_EU if wave==2
gen Approve_EU_w3 = Approve_EU if wave==3
norm Approve_EU_w2, method(zee)
norm Approve_EU_w3, method(zee)
gen zee_Approve_EU = zee_Approve_EU_w2
replace zee_Approve_EU = zee_Approve_EU_w3 if zee_Approve_EU==.

gen ECONOMY_w2 = ECONOMY if wave==2
gen ECONOMY_w3 = ECONOMY if wave==3
norm ECONOMY_w2, method(zee)
norm ECONOMY_w3, method(zee)
gen zee_ECONOMY = zee_ECONOMY_w2
replace zee_ECONOMY = zee_ECONOMY_w3 if zee_ECONOMY==.

gen trust_rep_w2 = trust_rep if wave==2
gen trust_rep_w3 = trust_rep if wave==3
norm trust_rep_w2, method(zee)
norm trust_rep_w3, method(zee)
gen zee_trust_rep = zee_trust_rep_w2
replace zee_trust_rep = zee_trust_rep_w3 if zee_trust_rep==.

*** Table
reg trust_EU_rep zee_AGE MAN zee_Education_mean L1.zee_IDEOLOGY L1.zee_INT_POL L1.zee_SOCIAL_TRUST L1.zee_F_ECON_INSECURE  L1.zee_GOV_APROVE L1.zee_Approve_EU L1.zee_ECONOMY L1.zee_trust_rep  
outreg2 using "Table_H.ster", replace ctitle(NULL) dec(2) onecol alpha(0.001,0.01,0.05,0.1) symbol(***,**,*,+)
outreg2 using "Table_H.xls",  excel replace  ctitle(NULL1)  dec(2) onecol alpha(0.001,0.01,0.05,0.1) symbol(***,**,*,+)


***********************************************************************************************************************
*** Within-Between Multilevel Model of Trust in the European Institutions in Spain (Table G in the Online Appendix) ***
***********************************************************************************************************************

xtmixed  CONFI_PARLAM_EU  || id: , var // Within Terms
estat icc
estat ic
outreg2 using "Table_G.ster", replace ctitle(NULL) dec(2) onecol alpha(0.001,0.01,0.05) symbol(***,**,*)
outreg2 using "Table_G.xls",  excel replace  ctitle(NULL1)  dec(2) onecol alpha(0.001,0.01,0.05) symbol(***,**,*)

xtmixed  CONFI_PARLAM_EU  zee_AGE_mean MAN zee_Education_mean  /// Time-invariant variables
zee_IDEOLOGY_mean  zee_INT_POL_mean  zee_SOCIAL_TRUST_mean  c.zee_F_ECON_INSECURE_mean c.zee_GOV_APROVE_mean zee_INFO_EU_mean zee_Approve_EU_mean c.zee_ECONOMY_mean c.zee_CONFI_PARLAM_mean /// Mean Terms
zee_IDEOLOGY_w  zee_INT_POL_w  zee_SOCIAL_TRUST_w  zee_F_ECON_INSECURE_w zee_ECONOMY_w zee_GOV_APROVE_w zee_INFO_EU_w zee_Approve_EU_w c.zee_CONFI_PARLAM_w || id: , var  // Within Terms     
outreg2 using "Table_G.ster", append ctitle(NULL) dec(2) onecol alpha(0.001,0.01,0.05) symbol(***,**,*)
outreg2 using "Table_G.xls",  excel append  ctitle(NULL1)  dec(2) onecol alpha(0.001,0.01,0.05) symbol(***,**,*)
estat icc
estat ic
estimates store CONFI_PARLAM_EU

xtmixed  CONFI_COMMISION_EU  || id: , var // Within Terms
estat icc
estat ic
outreg2 using "Table_G.ster", append ctitle(NULL) dec(2) onecol alpha(0.001,0.01,0.05) symbol(***,**,*)
outreg2 using "Table_G.xls",  excel append  ctitle(NULL1)  dec(2) onecol alpha(0.001,0.01,0.05) symbol(***,**,*)

xtmixed  CONFI_COMMISION_EU  zee_AGE_mean MAN zee_Education_mean  /// Time-invariant variables
zee_IDEOLOGY_mean  zee_INT_POL_mean  zee_SOCIAL_TRUST_mean  c.zee_F_ECON_INSECURE_mean c.zee_GOV_APROVE_mean zee_INFO_EU_mean zee_Approve_EU_mean c.zee_ECONOMY_mean c.zee_CONFI_GOVERNMENT_mean /// Mean Terms
zee_IDEOLOGY_w  zee_INT_POL_w  zee_SOCIAL_TRUST_w  zee_F_ECON_INSECURE_w  zee_ECONOMY_w zee_GOV_APROVE_w zee_INFO_EU_w zee_Approve_EU_w zee_CONFI_GOVERNMENT_w || id:  , var  // Within Terms     
outreg2 using "Table_G.ster", append ctitle(NULL) dec(2) onecol alpha(0.001,0.01,0.05) symbol(***,**,*)
outreg2 using "Table_G.xls",  excel append  ctitle(NULL1)  dec(2) onecol alpha(0.001,0.01,0.05) symbol(***,**,*)
estat icc
estat ic
estimates store CONFI_COMMISION_EU

*** Generate Marginal Effects Plot
* Within coefficients
coefplot (CONFI_PARLAM_EU, label(Trust in European Parliament)) (CONFI_COMMISION_EU, label(Trust in European Commission)), drop(_cons zee_AGE_mean MAN zee_Education_mean zee_IDEOLOGY_mean zee_INT_POL_mean zee_SOCIAL_TRUST_mean zee_F_ECON_INSECURE_mean zee_GOV_APROVE_mean zee_INFO_EU_mean zee_Approve_EU_mean zee_ECONOMY_mean zee_CONFI_PARLAM_mean zee_CONFI_GOVERNMENT_mean) xline(0)
* Between coefficients
coefplot (CONFI_PARLAM_EU, label(Trust in European Parliament)) (CONFI_COMMISION_EU, label(Trust in European Commission)), drop(_cons zee_IDEOLOGY_w zee_INT_POL_w zee_SOCIAL_TRUST_w zee_F_ECON_INSECURE_w zee_GOV_APROVE_w zee_INFO_EU_w zee_Approve_EU_w zee_ECONOMY_w zee_CONFI_PARLAM_w zee_CONFI_GOVERNMENT_w) xline(0)



